# -*- rpm-spec -*-
# $Id: kernel-image-std26-smp.spec,v 1.13 2004/08/18 12:18:03 vsu Exp $
#

# Version options
%define kernel_base_version	2.6.8
%define kernel_extra_version	%nil
# Numeric extra version scheme developed by Alexander Bokovoy:
# 0.0.X -- preX
# 0.X.0 -- rcX
# 1.0.0 -- release
%define kernel_extra_version_numeric 1.0.0
%define krelease alt9

%define base_flavour	std26
%define flavour		%base_flavour-smp

# Build options
# You can change compiler version by editing this line:
%define kgcc_version	3.3

# Enable/disable SGML docs formatting
%def_disable docs

# Fixes:
%add_patch_list kernel-fix-build
%add_patch_list kernel-fix-core
%add_patch_list kernel-fix-acpi
%add_patch_list kernel-fix-fs
%add_patch_list kernel-fix-drivers-net
%add_patch_list kernel-fix-drivers-scsi
%add_patch_list kernel-fix-drivers-usb
%add_patch_list kernel-fix-drivers-ide
%add_patch_list kernel-fix-security

# Feathures:

%add_patch_list kernel-feat-drivers-video-splash
%add_patch_list kernel-feat-drivers-input
%add_patch_list kernel-feat-drivers-lirc
%add_patch_list kernel-feat-drivers-pktcdvd
%add_patch_list kernel-feat-fs-squashfs
%add_patch_list	kernel-feat-net-ppp-mppe

# imz: Unicode support in VT/console
#add_patch_list kernel-feat-drivers-console-unicode
# Although this patch changes the interface between the kernel and loadkeys,
# I do not put a Conflicts for the old console-tools here,
# because the old loadkeys works fine the new kernel interface.

## Don't edit below this line ##################################

%define	kversion %kernel_base_version%kernel_extra_version

Name: kernel-image-%flavour
Version: %kversion
Release: %krelease

Summary: The Linux kernel (the core of the Linux operating system)
License: GPL
Group: System/Kernel and hardware
Url: http://www.kernel.org/
Packager: Anton Farygin <rider@altlinux.com>

Source1: config-%kernel_base_version-%flavour

ExclusiveOS: Linux

BuildRequires: coreutils dev86 bzip2 make tar flex
BuildRequires: rpm >= 4.0.2-75 libdb4-devel
BuildRequires: gcc%kgcc_version
BuildRequires: kernel-source-%{kernel_base_version} = %{kernel_extra_version_numeric}
BuildRequires: kernel-build-tools >= 0.7, modutils >= 2.4.27-alt1
BuildRequires: %get_patch_list

%if_enabled docs
BuildRequires: docbook-utils transfig ghostscript
%endif

%if_enabled ccache
BuildRequires: ccache
%endif

%ifdef use_ccache
BuildRequires: ccache
%endif

Requires: bootloader-utils >= 0.3-alt1, modutils >= 2.4.27-alt1, mkinitrd >= 1:2.9.1-alt1, startup >= 0.8.3-alt1
Provides: kernel = %kversion
Provides: alsa = 1.0.3

Prereq:		coreutils
Prereq:		modutils >= 2.4.27
Prereq:		mkinitrd >= 1:2.9.1-alt1
ExclusiveArch:	%ix86

%description
This package contains the Linux kernel that is used to boot and run
your system. It contains few device drivers for specific hardware.
Most hardware is instead supported by modules loaded after booting.
Patches included:%format_patch_list

%package -n kernel-headers-%flavour
Summary: Header files for the Linux kernel
Group: System/Kernel and hardware
Requires: kernel-headers-common >= 1.1.5
Provides: kernel-headers

%description -n kernel-headers-%flavour
These are the C header files for the Linux kernel, which define
structures and constants that are needed when building most standard
programs under Linux, as well as to rebuild the kernel.
Patches included:%format_patch_list

%package -n kernel-headers-modules-%flavour
Summary: Headers and other files needed for build kernel modules
Group: System/Kernel and hardware
Requires: kernel-headers-%flavour = %version-%release
Requires: gcc%kgcc_version

%description -n kernel-headers-modules-%flavour
These are the C headers and other files from the Linux kernel source tree, which define
structures and constants that are needed when building kernel modules only. 
Don't use it for any purposes except building a kernel modules.

%package -n kernel-doc-%base_flavour
Summary: Linux kernel %kversion documentation
Group: System/Kernel and hardware

%description -n kernel-doc-%base_flavour
This package contains documentation files for ALT Linux kernel packages:
 * kernel-image-%base_flavour-up-%kversion-%krelease
 * kernel-image-%base_flavour-smp-%kversion-%krelease

%prep

%setup -cT -n kernel-image-%flavour-%kversion-%krelease

%__rm -rf kernel-source-%kernel_base_version

%__tar -jxf %kernel_src/kernel-source-%kernel_base_version.tar.bz2

%setup -D -T -n kernel-image-%flavour-%kversion-%krelease/kernel-source-%kernel_base_version

echo "patches = %_patch_list"

%apply_patches 2.6

# this file should be usable both with make and sh (for broken modules
# which do not use the kernel makefile system)
echo 'export GCC_VERSION=%kgcc_version' > gcc_version.inc

%__subst 's/EXTRAVERSION[[:space:]]*=.*/EXTRAVERSION = %kernel_extra_version-%flavour-%krelease/g' Makefile
%__subst 's/CC.*$(CROSS_COMPILE)gcc/CC		= gcc-%kgcc_version/g' Makefile
# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -delete -or -name "*~" -delete

%build

KERNEL_BUILD_DIR=`pwd`

KernelVer=%kversion-%flavour-%krelease

echo "Building Kernel $KernelVer"

%__cp -vf %SOURCE1 arch/%base_arch/defconfig

%make_build mrproper

%make_build oldconfig

### It's a hack, but a useful hack:
cmp -s .config %SOURCE1 || %__cp -vf .config %SOURCE1

%make_build include/linux/version.h

%make_build V=1 bzImage

%make_build V=1 modules

echo "Kernel built $KernelVer"

%if_enabled docs
# psdocs, pdfdocs don't work yet
%make_build htmldocs
%endif

%install

KernelVer=%kversion-%flavour-%krelease

%__mkdir -p %buildroot/boot
%__install -m644 System.map %buildroot/boot/System.map-$KernelVer
%__install -m644 arch/i386/boot/bzImage %buildroot/boot/vmlinuz-$KernelVer
%__install .config %buildroot/boot/config-$KernelVer

%__make modules_install INSTALL_MOD_PATH=%buildroot

%__install -d %buildroot%_prefix/include/linux-%version-%flavour/include

pushd include
%__cp -a . %buildroot%_prefix/include/linux-%version-%flavour/include
popd

# drivers-headers install
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/drivers/scsi
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/drivers/char/drm
%__cp -a ./drivers/scsi/{{scsi,hosts,scsi_obsolete,scsi_typedefs}.h,scsi_module.c} \
	%buildroot%_prefix/src/linux-%version-%flavour/drivers/scsi/
%__cp -a ./drivers/char/drm/{drm,drm_os_linux,drmP,drm_proc}.h \
	%buildroot%_prefix/src/linux-%version-%flavour/drivers/char/drm/
pushd %buildroot%_prefix/src/linux-%version-%flavour
%__ln_s -f ../../include/linux-%version-%flavour/include ./include
popd

#%__install -d ${RPM_BUILD_ROOT}%_prefix/src/linux-%version-%flavour/drivers/media/video
#%__cp -a ./drivers/addon/bttv/{{id,bttv,bttvp,audiochip,i2c-compat,tuner,bt848}.h} \
#	${RPM_BUILD_ROOT}%_prefix/src/linux-%version-%flavour/drivers/media/video

%__install -d %buildroot%_prefix/src/linux-%version-%flavour/arch/%base_arch
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts/genksyms
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts/basic
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts/mod
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts/kconfig

%__cp -a ./Makefile %buildroot%_prefix/src/linux-%version-%flavour/
%__cp -a ./Module.symvers %buildroot%_prefix/src/linux-%version-%flavour/
%__cp -a ./arch/%base_arch/Makefile %buildroot%_prefix/src/linux-%version-%flavour/arch/%base_arch/

%__cp -a ./scripts/pnmtologo %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/mod/modpost %buildroot%_prefix/src/linux-%version-%flavour/scripts/mod/ 
%__cp -a ./scripts/mkversion %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/mod/mk_elfconfig %buildroot%_prefix/src/linux-%version-%flavour/scripts/mod/ 
%__cp -a ./scripts/kconfig/conf %buildroot%_prefix/src/linux-%version-%flavour/scripts/kconfig/ 
%__cp -a ./scripts/mkcompile_h %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/makelst %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.modpost %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.modinst %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.lib %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.clean %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.build %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/kallsyms %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/genksyms/genksyms %buildroot%_prefix/src/linux-%version-%flavour/scripts/genksyms 
%__cp -a ./scripts/basic/fixdep %buildroot%_prefix/src/linux-%version-%flavour/scripts/basic/
%__cp -a ./scripts/extract-ikconfig %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/conmakehash %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/checkversion.pl %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/checkincludes.pl %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/checkconfig.pl %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/bin2c %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/gcc-version.sh %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 


pushd %buildroot%_prefix/src/linux-%version-%flavour
ln -sf ../../include/linux-%version-%flavour/include include
popd

%__cp -a .config %buildroot%_prefix/src/linux-%version-%flavour/.config
%__cp -a gcc_version.inc %buildroot%_prefix/src/linux-%version-%flavour/
pushd %buildroot
%__rm -f %buildroot/lib/modules/$KernelVer/build
%__ln_s %_prefix/include/linux-%version-%flavour/ \
    %buildroot/lib/modules/$KernelVer/build
popd

# install documentation
%if_enabled docs
%__install -d %buildroot%_docdir/kernel-doc-%base_flavour-%version/
%__cp -a Documentation/* %buildroot%_docdir/kernel-doc-%base_flavour-%version/
%__install -d %buildroot%_docdir/kernel-doc-%base_flavour-%version/scsi/
for dir in aacraid; do
	%__install -d \
		%buildroot%_docdir/kernel-doc-%base_flavour-%version/scsi/$dir/
	%__cp -a drivers/scsi/$dir/README* \
		%buildroot%_docdir/kernel-doc-%base_flavour-%version/scsi/$dir/
done
%endif # if_enabled docs

%post
%post_kernel_image %kversion-%flavour-%krelease

%preun
%preun_kernel_image %kversion-%flavour-%krelease

%post -n kernel-headers-%flavour
%post_kernel_headers %kversion-%flavour-%krelease

%postun -n kernel-headers-%flavour
%postun_kernel_headers %kversion-%flavour-%krelease

%files
/boot/vmlinuz-%kversion-%flavour-%krelease
/boot/System.map-%kversion-%flavour-%krelease
%attr(644,root,root) /boot/config-%kversion-%flavour-%krelease
/lib/modules/%kversion-%flavour-%krelease
%exclude /lib/modules/%kversion-%flavour-%krelease/build

%files -n kernel-headers-%flavour
%dir %_prefix/include/linux-%version-%flavour
%dir %_prefix/include/linux-%version-%flavour/include
%_prefix/include/linux-%version-%flavour/include/acpi
%_prefix/include/linux-%version-%flavour/include/asm
%_prefix/include/linux-%version-%flavour/include/asm-%base_arch
%_prefix/include/linux-%version-%flavour/include/asm-generic
%_prefix/include/linux-%version-%flavour/include/config
%_prefix/include/linux-%version-%flavour/include/linux
%_prefix/include/linux-%version-%flavour/include/math-emu
%_prefix/include/linux-%version-%flavour/include/net
%_prefix/include/linux-%version-%flavour/include/pcmcia
%_prefix/include/linux-%version-%flavour/include/scsi
%_prefix/include/linux-%version-%flavour/include/video
/lib/modules/%version-%flavour-%krelease/build

%files -n kernel-headers-modules-%flavour
%_prefix/src/linux-%version-%flavour

%if_enabled docs
%files -n kernel-doc-%base_flavour
%doc %_docdir/kernel-doc-%base_flavour-%version
%endif

%changelog
* Wed Aug 18 2004 Sergey Vlasov <vsu@altlinux.ru> 2.6.8-alt9
- Added missing scripts/gcc-version.sh to kernel-headers-modules.
- Removed libkconfig.so shared library to avoid extra dependencies in packages.

* Mon Aug 16 2004 Anton Farygin <rider@altlinux.ru> 2.6.8-alt8
- 2.6.8
- added patch for fix typo in nfs code (2.6.8.1)
- updated acpi subsystem to last stable release (20040717)
- updated bootsplash

* Thu Aug 05 2004 Anton Farygin <rider@altlinux.ru> 2.6.7-alt8
- Updated kernel-fix-security:
    + fix ppos races (CAN-2004-0415)

* Thu Jun 17 2004 Anton Farygin <rider@altlinux.ru> 2.6.7-alt7
- 2.6.7
- updated bootsplash patch
- added kernel-fix-drivers-net:
  + 2.6_50_eql-check-null.patch: add NULL checks to the eql driver
  + 2.6_51_airo-proc-fix.patch: fix airo /proc write breakage
- added kernel-fix-drivers-usb:
  + 2.6_51_phidgetservo-fixes.patch: fix use of freed memory in PhidgetServo
    driver
  + 2.6_52_storage-jumpshot-fix.patch: fix size reporting in the Lexar Jumpshot
    CF driver; avoid "unneeded entry" message with some devices
- added kernel-fix-drivers-scsi:
  + 2.6_50_sata_sil-mod15write.patch: fix Seagate+SiI3112 mod15write bug
    workaround broken by the LBA48 optimizations

* Tue Jun 15 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt6
- kernel-fix-security added:
  + 2.6_50_fpu-exception.patch: fix FPU exception handling DoS

* Fri May 21 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt5
- updated to last kernel-fix-ide and kernel-fix-fs patches:
  + 2.6_55_reiserfs-i_size-race.patch: fix reiserfs inode size update race
    which could lead to file corruption
  + 2.6_52_no-suspend-on-reboot.patch: replaced with better fix (flush drive
    cache on reboot)
  + 2.6_51_dquot_release-oops.patch: fix dquot_release oops with quota_v1
  + 2.6_52_quota-recursion.patch: fixes quota recursion into filesystem
  + 2.6_53_quota-recursion-fix.patch: fix the recursion fix
  + 2.6_54_quota-v2-corruption.diff: fix possible quota_v2 files corruption
    when root did not have any inodes&space allocated
- added kernel-feat-pktcdvd

* Mon May 17 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt4
- config tuning:
    CONFIG_BLK_DEV_ATIIXP=y
    CONFIG_IP_NF_MATCH_IPRANGE=m
    CONFIG_IP_NF_MATCH_PHYSDEV=m
    * disabled debug on i2c
    * enabled ebtables
    * disabled CONFIG_FONT_MINI_4x6
    * moved CONFIG_X86_MCE_NONFATAL to modules
    * disabled CONFIG_IDEDMA_IVB
- added kernel-fix-drivers-ide (Sergey Vlasov) with:
  + 2.6_50_wcache-fixes.patch: fix write cache handling problems:
    + fix drive->wcache setting
    + send CACHE FLUSH (EXT) only if the drive claims to support it
    + fix for Maxtor disks falsely claiming CACHE FLUSH EXT support
  + 2.6_51_system_state.patch: differentiate between halt/poweroff/reboot
  + 2.6_52_no-suspend-on-reboot.patch: avoid drive spindown on reboot
    
* Tue May 11 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt3
- 2.6.6
- fixed depends (kernel-headers-modules)
- added kernel-fix-acpi with:
    fixes IRQ12 sharing
- Added kernel-feat-drivers-console-unicode by Ivan Zakharyaschev <imz@altlinux.ru>:
  fixes the imperfectness of Linux VT/console Unicode support 
  (involves a change of the kernel interface used by loadkeys, 
  but mainly is compatible with old loadkeys).

* Mon Apr 05 2004 Anton Farygin <rider@altlinux.ru> 2.6.5-alt1
- update to 2.6.5
- updated patches and config from std26-up-2.6.5-alt1 kernel

* Thu Mar 22 2004 Anton Farygin <rider@altlinux.ru> 2.6.4-alt4
- first build for Sisyphus, based on kernel-image-std26-up with changes:
    enabled CONFIG_HIGHMEM64G
    enabled CONFIG_X86_SMP (CONFIG_NR_CPUS=8)
    enabled CONFIG_X86_HT
    enabled CONFIG_IRQBALANCE
    enabled CONFIG_MPENTIUM4
    
